SF.net SVN: geany: [752] trunk

eht16 at users.sourceforge.net eht16 at xxxxx
Mon Aug 21 17:07:52 UTC 2006


Revision: 752
Author:   eht16
Date:     2006-08-21 10:07:44 -0700 (Mon, 21 Aug 2006)
ViewCVS:  http://svn.sourceforge.net/geany/?rev=752&view=rev

Log Message:
-----------
Enlarged the tab close icon. This should fix some display issues.

Modified Paths:
--------------
    trunk/ChangeLog
    trunk/src/images.c
    trunk/src/notebook.c
Modified: trunk/ChangeLog
===================================================================
--- trunk/ChangeLog	2006-08-20 20:39:59 UTC (rev 751)
+++ trunk/ChangeLog	2006-08-21 17:07:44 UTC (rev 752)
@@ -1,3 +1,10 @@
+2006-08-21  Enrico Tröger  <enrico.troeger at uvena.de>
+
+ * src/images.c, src/notebook.c:
+   Applied patch from Củ Văn Chuối to enlarge the tab close icon. This
+   should fix some display issues.
+
+
 2006-08-20  Enrico Tröger  <enrico.troeger at uvena.de>
 
  * src/build.c, src/document.c, src/document.h, src/geany.h,

Modified: trunk/src/images.c
===================================================================
--- trunk/src/notebook.c	2006-08-20 20:39:59 UTC (rev 751)
+++ trunk/src/notebook.c	2006-08-21 17:07:44 UTC (rev 752)
@@ -259,7 +259,7 @@
 	gtk_container_add(GTK_CONTAINER(but),
 		utils_new_image_from_inline(GEANY_IMAGE_SMALL_CROSS, FALSE));
 	gtk_container_set_border_width(GTK_CONTAINER(but), 0);
-	gtk_widget_set_size_request(but, 17, 15);
+	gtk_widget_set_size_request(but, 19, 18);
 
 	align = gtk_alignment_new(1.0, 0.0, 0.0, 0.0);
 	gtk_container_add(GTK_CONTAINER(align), but);


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Commits mailing list
--- trunk/src/images.c	2006-08-20 20:39:59 UTC (rev 751)
+++ trunk/src/images.c	2006-08-21 17:07:44 UTC (rev 752)
@@ -218,26 +218,25 @@
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
-  /* length: header (24) + pixel_data (196) */
-  "\0\0\0\334"
-  /* pixdata_type (0x1010002) */
-  "\1\1\0\2"
-  /* rowstride (28) */
-  "\0\0\0\34"
-  /* width (7) */
-  "\0\0\0\7"
-  /* height (7) */
-  "\0\0\0\7"
+  /* length: header (24) + pixel_data (171) */
+  "\0\0\0\303"
+  /* pixdata_type (0x2010002) */
+  "\2\1\0\2"
+  /* rowstride (40) */
+  "\0\0\0("
+  /* width (10) */
+  "\0\0\0\12"
+  /* height (10) */
+  "\0\0\0\12"
   /* pixel_data: */
-  "\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0"
-  "\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377"
-  "\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\377\0\0\0\377"};
+  "\2\0\0\0\10\0\0\0\35\206\0\0\0\0\202\0\0\0\15\1\0\0\0\1\202\0\0\0\377"
+  "\204\0\0\0\0\202\0\0\0\377\2\0\0\0\31\0\0\0\0\203\0\0\0\377\202\0\0\0"
+  "\0\203\0\0\0\377\203\0\0\0\0\206\0\0\0\377\205\0\0\0\0\204\0\0\0\377"
+  "\206\0\0\0\0\204\0\0\0\377\205\0\0\0\0\206\0\0\0\377\203\0\0\0\0\203"
+  "\0\0\0\377\202\0\0\0\0\203\0\0\0\377\2\0\0\0\0\0\0\0\13\202\0\0\0\377"
+  "\204\0\0\0\0\202\0\0\0\377\202\0\0\0\22\1\0\0\0\11\206\0\0\0\0\2\0\0"
+  "\0\21\0\0\0\40"};
 
-
 /* GdkPixbuf RGBA C-Source image dump */
 
 #ifdef __SUNPRO_C

Modified: trunk/src/notebook.c
===================================================================